within ;
package AdrenergicReceptors
  "Alpha and beta receptors model, reacting on sypathetic activity and on catecholamines such as epinephrine or norepinephrine"

  class References "References"
    extends Modelica.Icons.References;

    annotation (Documentation(info="<html>
<table cellspacing=\"2\" cellpadding=\"0\" border=\"0\"><tr>
<td><p>[Ahlquist1948]</p></td>
<td><p>Ahlquist RP A study of adrenergic receptors. Am J Physiol 153:586-600, 1948</p></td>
</tr>
<tr>
<td><p>[Berthelson1977]</p></td>
<td><p>Berthelson S, Pettinger WA. A functional basis for classification of alpha-adrenergic receptors. Life Sci 21: 595-606, 1977</p></td>
</tr>
<tr>
<td><h4>[Besse1967]</h4></td>
<td><h4>Besse J, Furchgott R. &QUOT;Dissociation constants and relative efficacies of agonists acting on adrenergic alpha-receptors.&QUOT; Fed Proc 26: 410, 1967</h4></td>
</tr>
<tr>
<td><p>[Bylund2005]</p></td>
<td><p>Bylund DB Adrenergic receptors: historical perspectives from the 20th century. In: The Adrenergic Receptors in the 21st century. Edited by DM Perez. Totowa:Humana, 2005, Pg 3-21</p></td>
</tr>
<tr>
<td><h4>[Black1983]</h4></td>
<td><h4>Black JW, Leff P. &QUOT;Operational models of pharmacological agonism.&QUOT; Proc R. Soc Lond 220: 141-162, 1983. </h4></td>
</tr>
<tr>
<td><p>[Dale1906]</p></td>
<td><p>Dale HH J Physiol 34:163, 1906</p></td>
</tr>
<tr>
<td><p>[Lands1967]</p></td>
<td><p>Lands AM, Arnold A, McAuliff JP, Luduena FP, Brown Jr. TG Differentiation of receptor systems activated by sympathomimetic amines. Nature 214: 597-598, 1967</p></td>
</tr>
<tr>
<td><p>[Langley1905]</p></td>
<td><p>Langley JN J Physiol 33:374, 1905</p></td>
</tr>
</table>
</html>"));
  end References;

  partial model AdrenergicReceptorInterface
    extends Physiolibrary.Icons.Hormones;

    Physiolibrary.Types.BusConnector busConnector
      annotation (Placement(transformation(extent={{-26,78},{14,118}}),
          iconTransformation(extent={{-26,78},{14,118}})));
    Physiolibrary.Types.RealIO.FractionOutput activity
      "Normalized receptor activity"                                                  annotation (Placement(
          transformation(extent={{100,-10},{120,10}}), iconTransformation(extent={
              {100,-10},{120,10}})));
    annotation (Icon(coordinateSystem(preserveAspectRatio=false, extent={{-100,-100},
              {100,100}}), graphics), Diagram(coordinateSystem(
            preserveAspectRatio=false, extent={{-100,-100},{100,100}}), graphics));
  end AdrenergicReceptorInterface;

  model Inputs "Example of subsystem inputs"
   //  extends Physiolibrary.Types.IO_Bus.InputFromFile;
   import T = Physiolibrary.Types.RealTypeInputParameters;

    Physiolibrary.Types.BusConnector
                 busConnector annotation (Placement(transformation(extent={{82,38},
              {102,58}}),        iconTransformation(extent={{90,70},{110,90}})));
    T.Concentration Epinephrine(varName="EpiPool.[Epi(nMol/L)]", k(displayUnit="nmol/l")=
           2e-07) "Epinephrine concentration"
    annotation (Placement(transformation(extent={{-54,10},{28,92}})));
    T.Concentration Norepinephrine(varName="NEPool.[NE(nMol/L)]", k(displayUnit="nmol/l")=
           1.4e-06) "Norepinephrine concentration"
    annotation (Placement(transformation(extent={{-54,-18},{28,64}})));
    T.Frequency Sympathetic(                            k(displayUnit="Hz") = 1.5,
      varName="GangliaGeneral.NA(Hz)",
      storeUnit="Hz") "Sympathetic nervous system activity"
      annotation (Placement(transformation(extent={{-54,42},{28,124}})));
    T.Concentration Isoproterenol(k(displayUnit="%") = 0, varName="Isoproterenol")
      "Isoproterenol as Beta Receptor agonist"
      annotation (Placement(transformation(extent={{20,-94},{60,-62}})));
    T.Concentration Phenylephrine(k(displayUnit="%") = 0, varName="Phenylephrine")
      "Phenylephrine as alpha receptor agonist"
      annotation (Placement(transformation(extent={{20,-106},{60,-72}})));
    T.Concentration Desglymidodrine(
      k(displayUnit="%") = 0,
      varName="DesglymidodrinePool.[Desglymidodrine]",
      storeUnit="ug/l") "Desglymidodrine as alpha Receptor agonist "
      annotation (Placement(transformation(extent={{20,-84},{60,-48}})));
    T.Concentration Propranolol(k(displayUnit="%") = 0, varName="Propranolol")
      "Propranolol as Beta-1 and Beta-2 Receptor blockers"
      annotation (Placement(transformation(extent={{-96,-30},{-56,2}})));
    T.Concentration Metoprolol(k(displayUnit="%") = 0, varName="Metoprolol")
      "Metoprolol as Beta-1 Receptor blockers"
      annotation (Placement(transformation(extent={{-96,-42},{-56,-10}})));
    T.Concentration Phenoxybenzamine(k(displayUnit="%") = 0, varName=
          "Phenoxybenzamine")
      "Phenoxybenzamine as non-selective alpha-adrenergic blockers"
      annotation (Placement(transformation(extent={{-74,-76},{-34,-44}})));
    T.Concentration Doxazosin(k(displayUnit="%") = 0, varName="Doxazosin")
      "Doxazosin as alpha-1 adrenergic blockers"
      annotation (Placement(transformation(extent={{-74,-88},{-34,-56}})));
    T.Concentration Mitrazapine(k(displayUnit="%") = 0, varName="Mitrazapine")
      "Mitrazapine as alpha-2 adrenergic blockers"
      annotation (Placement(transformation(extent={{-74,-100},{-34,-68}})));
    annotation (experiment(StopTime=1), Diagram(coordinateSystem(
            preserveAspectRatio=false, extent={{-100,-100},{100,100}}), graphics={
          Text(
            extent={{-74,-42},{-34,-52}},
            lineColor={0,0,255},
            textString="alpha blockers"),
          Text(
            extent={{-96,2},{-56,-8}},
            lineColor={0,0,255},
            textString="beta blockers"),
          Text(
            extent={{20,-48},{60,-58}},
            lineColor={0,0,255},
            textString="agonist")}),
      Icon(coordinateSystem(preserveAspectRatio=false, extent={{-100,-100},{100,100}}),
          graphics));
  equation
    connect(Epinephrine.y, busConnector.Epinephrine) annotation (Line(
        points={{38.25,51},{70,51},{70,48},{92,48}},
        color={0,0,127},
        smooth=Smooth.None), Text(
        string="%second",
        index=1,
        extent={{6,3},{6,3}}));
    connect(Norepinephrine.y, busConnector.Norepinephrine) annotation (Line(
        points={{38.25,23},{70,23},{70,48},{92,48}},
        color={0,0,127},
        smooth=Smooth.None), Text(
        string="%second",
        index=1,
        extent={{6,3},{6,3}}));
    connect(Sympathetic.y, busConnector.GangliaGeneral_NA) annotation (Line(
        points={{38.25,83},{74,83},{74,48},{92,48}},
        color={0,0,127},
        smooth=Smooth.None), Text(
        string="%second",
        index=1,
        extent={{6,3},{6,3}}));
    connect(Desglymidodrine.y, busConnector.Desglymidodrine) annotation (Line(
        points={{65,-66},{92,-66},{92,48}},
        color={0,0,127},
        smooth=Smooth.None), Text(
        string="%second",
        index=1,
        extent={{6,3},{6,3}}));
    connect(Isoproterenol.y, busConnector.Isoproterenol) annotation (Line(
        points={{65,-78},{92,-78},{92,48}},
        color={0,0,127},
        smooth=Smooth.None), Text(
        string="%second",
        index=1,
        extent={{6,3},{6,3}}));
    connect(Phenylephrine.y, busConnector.Phenylephrine) annotation (Line(
        points={{65,-89},{92,-89},{92,48}},
        color={0,0,127},
        smooth=Smooth.None), Text(
        string="%second",
        index=1,
        extent={{6,3},{6,3}}));
    connect(Propranolol.y, busConnector.Propranolol) annotation (Line(
        points={{-51,-14},{82,-14},{82,48},{92,48}},
        color={0,0,127},
        smooth=Smooth.None), Text(
        string="%second",
        index=1,
        extent={{6,3},{6,3}}));
    connect(Metoprolol.y, busConnector.Metoprolol) annotation (Line(
        points={{-51,-26},{-18,-26},{-18,-14},{82,-14},{82,48},{92,48}},
        color={0,0,127},
        smooth=Smooth.None), Text(
        string="%second",
        index=1,
        extent={{6,3},{6,3}}));
    connect(Phenoxybenzamine.y, busConnector.Phenoxybenzamine) annotation (Line(
        points={{-29,-60},{8,-60},{8,-36},{82,-36},{82,48},{92,48}},
        color={0,0,127},
        smooth=Smooth.None), Text(
        string="%second",
        index=1,
        extent={{6,3},{6,3}}));
    connect(Doxazosin.y, busConnector.Doxazosin) annotation (Line(
        points={{-29,-72},{8,-72},{8,-36},{82,-36},{82,48},{92,48}},
        color={0,0,127},
        smooth=Smooth.None), Text(
        string="%second",
        index=1,
        extent={{6,3},{6,3}}));
    connect(Mitrazapine.y, busConnector.Mitrazapine) annotation (Line(
        points={{-29,-84},{8,-84},{8,-36},{82,-36},{82,48},{92,48}},
        color={0,0,127},
        smooth=Smooth.None), Text(
        string="%second",
        index=1,
        extent={{6,3},{6,3}}));
  end Inputs;
  annotation (uses(Physiolibrary(version="2.2.0"), Modelica(version=
            "3.2.1")));
end AdrenergicReceptors;
