within ;
package SinoatrialNode
  class References "References"
    extends Modelica.Icons.References;

    annotation (Documentation(info="<html>
<table cellspacing=\"2\" cellpadding=\"0\" border=\"0\">
<tr>
<td><p>[Bazett1997]</p></td>
<td><p>H. C. Bazett, &QUOT;AN ANALYSIS OF THE TIME-RELATIONS OF ELECTROCARDIOGRAMS,&QUOT; Annals of Noninvasive Electrocardiology, vol. 2, pp. 177-194, 1997.</p></td>
</tr>
<tr>
<td><p>[Bootsma1994]</p></td>
<td><p>M. Bootsma, C. A. Swenne, H. H. Van Bolhuis, P. C. Chang, V. M. Cats, and A. Bruschke, &QUOT;Heart rate and heart rate variability as indexes of sympathovagal balance,&QUOT; American Journal of Physiology, vol. 266, pp. H1565-H1565, 1994. </p></td>
</tr>
<tr>
<td><p>[Ferguson1985]</p></td>
<td><p>D. W. Ferguson, F. M. Abboud, and A. L. Mark, &QUOT;Relative contribution of aortic and carotid baroreflexes to heart rate control in man during steady state and dynamic increases in arterial pressure,&QUOT; The Journal of Clinical Investigation, vol. 76, pp. 2265-2274, 1985.</p></td>
</tr>
<tr>
<td><p>[Kumagai1994]</p></td>
<td><p>K. Kumagai and I. A. Reid, &QUOT;Angiotensin II exerts differential actions on renal nerve activity and heart rate,&QUOT; Hypertension, vol. 24, pp. 451-456, 1994. </p></td>
</tr>
<tr>
<td><p>[Raeder1995]</p></td>
<td><p>E. A. Raeder, P. Albrecht, M. Perrott, and R. J. Cohen, &QUOT;Kinetics of Cycle Length Dependence of Ventricular Repolarization,&QUOT; Journal of Cardiovascular Electrophysiology, vol. 6, pp. 163-169, 1995.</p></td>
</tr>
<tr>
<td><p>[ROSS1965]</p></td>
<td><p>J. ROSS, J. W. LINHART, and E. BRAUNWALD, &QUOT;Effects of Changing Heart Rate in Man by Electrical Stimulation of the Right Atrium: Studies at Rest, during Exercise, and with Isoproterenol,&QUOT; Circulation, vol. 32, pp. 549-558, October 1, 1965 1965. </p></td>
</tr>
<tr>
<td><p>[Sugimoto1966]</p></td>
<td><p>T. Sugimoto, K. Sagawa, and A. Guyton, Effect of tachycardia on cardiac output during normal and increased venous return vol. 211, 1966.</p></td>
</tr>
<tr>
<td><p>[Takeshita1979]</p></td>
<td><p>A. Takeshita, A. L. Mark, D. L. Eckberg, and F. M. Abboud, Effect of central venous pressure on arterial baroreflex control of heart rate vol. 236, 1979.</p></td>
</tr>
<tr>
<td><h4>[Warner1962]</h4></td>
<td><h4>H. R. Warner and A. Cox, A mathematical model of heart rate control by sympathetic and vagus efferent information vol. 17, 1962. </h4></td>
</tr>
</table>
</html>"));
  end References;

  model SANode "Sinoatrial node"
   extends Physiolibrary.Icons.SinoatrialNode;

    Physiolibrary.Types.RealIO.FractionInput betaReceptors
      annotation (Placement(transformation(extent={{-120,40},{-80,80}})));
    Physiolibrary.Types.RealIO.FractionInput cholinergicReceptors
      annotation (Placement(transformation(extent={{-120,0},{-80,40}})));
    Physiolibrary.Types.RealIO.FrequencyOutput heartRate
      annotation (Placement(transformation(extent={{100,-10},{120,10}})));
    Physiolibrary.Types.RealIO.FractionInput heartMechanoreceptors
      "heart mechanoreceptors"
      annotation (Placement(transformation(extent={{-120,-80},{-80,-40}})));
    annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
              -100},{100,100}}), graphics));
  end SANode;

  model Inputs "Example of subsystem inputs"
   //  extends Physiolibrary.Types.IO_Bus.InputFromFile;
   import T = Physiolibrary.Types.RealTypeInputParameters;


    Physiolibrary.Types.RealIO.FractionOutput SANodeBetaReceptors annotation (
        Placement(transformation(extent={{100,-50},{120,-30}}),
          iconTransformation(extent={{100,-50},{120,-30}})));
    Physiolibrary.Types.RealIO.FractionOutput SANodeCholinergicReceptors
      annotation (Placement(transformation(extent={{100,-90},{120,-70}}),
          iconTransformation(extent={{100,-90},{120,-70}})));
    T.Fraction SANodeBetaReceptorsActivity(varName=
          "SANode-BetaReceptors.Activity", k=1)
      "Normalized Sinoatrial Node Beta-Receptors Activity"
      annotation (Placement(transformation(extent={{-80,-80},{0,0}})));
    T.Fraction SANodeCholinergicReceptorsActivity(varName=
          "SANode-CholinergicReceptors.Activity", k=1)
      "Normalized Sinoatrial Node Cholinergic-Receptors Activity"
      annotation (Placement(transformation(extent={{-80,-120},{0,-40}})));
    annotation (experiment(StopTime=1), Diagram(coordinateSystem(
            preserveAspectRatio=false, extent={{-100,-100},{100,100}}), graphics),
      Icon(coordinateSystem(preserveAspectRatio=false, extent={{-100,-100},{100,
              100}}),
          graphics));
  equation
    connect(SANodeBetaReceptorsActivity.y, SANodeBetaReceptors) annotation (
        Line(
        points={{10,-40},{110,-40}},
        color={0,0,127},
        smooth=Smooth.None));
    connect(SANodeCholinergicReceptorsActivity.y, SANodeCholinergicReceptors)
      annotation (Line(
        points={{10,-80},{110,-80}},
        color={0,0,127},
        smooth=Smooth.None));
  end Inputs;
  annotation (uses(Physiolibrary(version="2.2.0"), Modelica(version=
            "3.2.1")));
end SinoatrialNode;
